==> varbase_layout_builder-10.0.13.tar.gz: varbase_layout_builder/README.md <==
# Varbase Layout Builder

Provides default configuration and enhancements to utilize Drupal core's Layout Builder.

Utilizing the [Bootstrap Layout Builder](https://www.drupal.org/project/bootstrap_layout_builder) module. Optimized for Varbase standard layouts and styling configurations. Having custom Layout options, and custom styling plugins.

## Varbase Landing Page (Layout Builder)
Having a Landing page (Layout Builder) content type and related configuration. To be used for building pages with custom sections and layouts to display content in a modern way.

## Ready Block Types:
### Varbase Heading block
A heading block is used to add headings to your page or sections. Headings help structure your page making your content easier to read by humans and search engines.

### Varbase Rich text block
A rich text block contains a title and a body with a rich text format.

### Varbase HTML code block
An HTML Code block contains a title and a body with an HTML text format.

### Varbase Media (image/video) block
A media block contains a title and media.

### Varbase Gallery block
A gallery block contains a title and a gallery of images and videos.


## Use With [Varbase](https://www.drupal.org/project/varbase) Distribution:
This module is best used with [Varbase](https://www.drupal.org/project/varbase) distribution.

Varbase Layout Builder can be installed with any Drupal 8/9 site. Even if installed with the Minimal or Standard profile.
However, using it with [Varbase](https://www.drupal.org/project/varbase) gives you way much more cool stuff!

# [Varbase documentation](https://docs.varbase.vardot.com/dev-docs/understanding-varbase/core-components/varbase-layout-builder)
Check out Varbase documentation for more details.

Join Our Slack Team for Feedback and Support
Join now: http://slack.varbase.vardot.com/

This module is sponsored and developed by [Vardot](https://www.drupal.org/vardot).

==> varbase_layout_builder-10.0.58.tar.gz: varbase_layout_builder/README.md <==
# Varbase Layout Builder

Provides default configuration and enhancements to utilize
 Drupal core's Layout Builder.

Utilizing the [Bootstrap Layout Builder](https://www.drupal.org/project/bootstrap_layout_builder) module. Optimized for Varbase standard layouts and styling configurations. Having custom Layout options, and custom styling plugins.

## Varbase Landing Page (Layout Builder)
Having a Landing page (Layout Builder) content type and related configuration.

To be used for building pages with custom sections and layouts to display
 content in a modern way.

## Ready Block Types:
### Varbase Heading block
A heading block is used to add headings to your page or sections.
Headings help structure your page making your content easier to
read by humans and search engines.

### Varbase Rich text block
A rich text block contains a title and a body with a rich text format.

### Varbase HTML code block
An HTML Code block contains a title and a body with an HTML text format.

### Varbase Media (image/video) block
A media block contains a title and media.

### Varbase Gallery block
A gallery block contains a title and a gallery of images and videos.


## Use With [Varbase](https://www.drupal.org/project/varbase) Distribution:
This module is best used with [Varbase](https://www.drupal.org/project/varbase) distribution.

Varbase Layout Builder can be installed with any Drupal 8/9/10 site.
Even if installed with the Minimal or Standard profile.

However, using it with [Varbase](https://www.drupal.org/project/varbase) gives you way much more cool stuff!

# [Varbase documentation](https://docs.varbase.vardot.com/dev-docs/understanding-varbase/core-components/varbase-layout-builder)
Check out Varbase documentation for more details.

Join Our Slack Team for Feedback and Support
Join now: http://slack.varbase.vardot.com/

Sponsored and developed by [Vardot](https://www.drupal.org/vardot).
